Index: /branches/eam_branches/ipp-20230313/Ohana/src/opihi/dvo/avselect.c
===================================================================
--- /branches/eam_branches/ipp-20230313/Ohana/src/opihi/dvo/avselect.c	(revision 42425)
+++ /branches/eam_branches/ipp-20230313/Ohana/src/opihi/dvo/avselect.c	(revision 42426)
@@ -22,4 +22,5 @@
 
   Vector **vec, **invec, *RAvec, *DECvec, *IDXvec, *RADvec;
+  Vector *RINvec = NULL;
   dbField *fields;
   dbValue *values;
@@ -102,7 +103,17 @@
   }
 
-  RADIUS = atof (argv[1]);
-
-  /* load regions which contain all supplied RA,DEC coordinates */
+  if (SelectScalar (argv[1], &RADIUS)) {
+    remove_argument (1, &argc, argv);
+  } else {
+    gprint (GP_ERR, " RADIUS must be a numerical value\n");
+    goto help;
+    if ((RINvec = SelectVector (argv[1], ANYVECTOR, TRUE)) == NULL) goto help;
+    RADIUS = 0.0; // find the max radius for region selection:
+    for (i = 0; i < RINvec->Nelements; i++) {
+      RADIUS = MAX(RINvec->elements.Flt[i], RADIUS);
+    }
+  }
+
+  /* load regions which contain all supplied RA,DEC coordinates (for RINvec, uses max radius) */
   if ((skylist = SelectRegionsByCoordVectorsAndRadius (RAvec, DECvec, RADIUS/3600.0)) == NULL) goto escape;
 
@@ -167,7 +178,4 @@
     return status;
   }
-
-  RADIUS = atof (argv[1]);
-  remove_argument (1, &argc, argv);
 
   // parse the fields to be extracted and returned
